==> upload-api-client-internal-2.25.0.tgz: package/src/services/FoldersService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolder } from "../models/DeleteFolder";
import type { DeleteFolderBatch } from "../models/DeleteFolderBatch";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenLimit } from "../models/ListFolderChildrenLimit";
import type { ListFolderChildrenResult } from "../models/ListFolderChildrenResult";
import type { MakeFolder } from "../models/MakeFolder";
import { request as __request } from "../core/request";

export class FoldersService {
  /**
   * The "make folder" endpoint behaves like an upsert, creating the folder if it doesn't exist, and updating it otherwise.
   * If the folder's ancestors don't exist, they will be created using empty folder settings.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async makeFolder(accountId: AccountId, requestBody: MakeFolder): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolder(accountId: AccountId, requestBody: DeleteFolder): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolderBatch(accountId: AccountId, requestBody: DeleteFolderBatch): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * @param accountId
   * @param path
   * @param includeFolders
   * @param includeFiles
   * @param traverseVirtualFolders
   * @param limit
   * @param cursor
   * @returns ListFolderChildrenResult Success.
   * @throws ApiError
   */
  public static async listChildren(
    accountId: AccountId,
    path: FolderPath,
    includeFolders?: boolean,
    includeFiles?: boolean,
    traverseVirtualFolders?: boolean,
    limit?: ListFolderChildrenLimit,
    cursor?: ListFolderChildrenCursor
  ): Promise<ListFolderChildrenResult> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders/children`,
      query: {
        path: path,
        includeFolders: includeFolders,
        includeFiles: includeFiles,
        traverseVirtualFolders: traverseVirtualFolders,
        limit: limit,
        cursor: cursor
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.29.0.tgz: package/src/services/FoldersService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenLimit } from "../models/ListFolderChildrenLimit";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
import { request as __request } from "../core/request";

export class FoldersService {
  /**
   * Creates or updates the folder specified by "folderPath". If the folder's ancestors don't exist, they will be created automatically. Required API key type: 'secret_*' only.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes a folder. Required API key type: 'secret_*' only.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes multiple folders. Required API key type: 'secret_*' only.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolderBatch(
    accountId: AccountId,
    requestBody: DeleteFolderBatchRequest
  ): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the children (files and sub-folders) of a folder. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param folderPath
   * @param includeFolders
   * @param includeFiles
   * @param traverseVirtualFolders
   * @param limit
   * @param cursor
   * @returns ListFolderChildrenResponse Success.
   * @throws ApiError
   */
  public static async listFolderChildren(
    accountId: AccountId,
    folderPath: FolderPath,
    includeFolders?: boolean,
    includeFiles?: boolean,
    traverseVirtualFolders?: boolean,
    limit?: ListFolderChildrenLimit,
    cursor?: ListFolderChildrenCursor
  ): Promise<ListFolderChildrenResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders/children`,
      query: {
        folderPath: folderPath,
        includeFolders: includeFolders,
        includeFiles: includeFiles,
        traverseVirtualFolders: traverseVirtualFolders,
        limit: limit,
        cursor: cursor
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
